﻿/*
Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'colorbutton', 'bn', {
	auto: 'স্বয়ংক্রিয়ভাবে',
	bgColorTitle: 'পৃষ্ঠতলের রং',
	colors: {
		'000': 'Black',
		'800000': 'Maroon',
		'8B4513': 'Saddle Brown',
		'2F4F4F': 'Dark Slate Gray',
		'008080': 'Teal',
		'000080': 'Navy',
		'4B0082': 'Indigo',
		'696969': 'Dark Gray',
		B22222: 'Fire Brick',
		A52A2A: 'Brown',
		DAA520: 'Golden Rod',
		'006400': 'Dark Green',
		'40E0D0': 'Turquoise',
		'0000CD': 'Medium Blue',
		'800080': 'Purple',
		'808080': 'Gray',
		F00: 'Red',
		FF8C00: 'Dark Orange',
		FFD700: 'Gold',
		'008000': 'Green',
		'0FF': 'Cyan',
		'00F': 'Blue',
		EE82EE: 'Violet',
		A9A9A9: 'Dim Gray',
		FFA07A: 'Light Salmon',
		FFA500: 'Orange',
		FFFF00: 'Yellow',
		'00FF00': 'Lime',
		AFEEEE: 'Pale Turquoise',
		ADD8E6: 'Light Blue',
		DDA0DD: 'Plum',
		D3D3D3: 'Light Grey',
		FFF0F5: 'Lavender Blush',
		FAEBD7: 'Antique White',
		FFFFE0: 'Light Yellow',
		F0FFF0: 'Honeydew',
		F0FFFF: 'Azure',
		F0F8FF: 'Alice Blue',
		E6E6FA: 'Lavender',
		FFF: 'White',
		'1ABC9C': 'Strong Cyan', // MISSING
		'2ECC71': 'Emerald', // MISSING
		'3498DB': 'Bright Blue', // MISSING
		'9B59B6': 'Amethyst', // MISSING
		'4E5F70': 'Grayish Blue', // MISSING
		'F1C40F': 'Vivid Yellow', // MISSING
		'16A085': 'Dark Cyan', // MISSING
		'27AE60': 'Dark Emerald', // MISSING
		'2980B9': 'Strong Blue', // MISSING
		'8E44AD': 'Dark Violet', // MISSING
		'2C3E50': 'Desaturated Blue', // MISSING
		'F39C12': 'Orange', // MISSING
		'E67E22': 'Carrot', // MISSING
		'E74C3C': 'Pale Red', // MISSING
		'ECF0F1': 'Bright Silver', // MISSING
		'95A5A6': 'Light Grayish Cyan', // MISSING
		'DDD': 'Light Gray', // MISSING
		'D35400': 'Pumpkin', // MISSING
		'C0392B': 'Strong Red', // MISSING
		'BDC3C7': 'Silver', // MISSING
		'7F8C8D': 'Grayish Cyan', // MISSING
		'999': 'Dark Gray' // MISSING
	},
	more: 'আরও রং...',
	panelTitle: 'Colors',
	textColorTitle: 'টেক্স্ট রং'
} );
